/*! app.js v0.0.6 | https://www.npmjs.com/package/app-methods */
(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
	typeof define === 'function' && define.amd ? define(['exports'], factory) :
	(factory((global.app = global.app || {})));
}(this, (function (exports) { 'use strict';

/* global App:false */
/**
 * @file 「Ping」的方法
 */
function hideBar$1 () {
  try {
    App.hideBar();
  } catch (e) {}
}

function showBar$1 () {
  try {
    App.showBar();
  } catch (e) {}
}

function exit$1 () {
  try {
    App.close();
  } catch (e) {}
}


var ping = Object.freeze({
	hideBar: hideBar$1,
	showBar: showBar$1,
	exit: exit$1
});

var ua = navigator.userAgent.toLowerCase();

/* global yasuo:false */
/**
 * @file 「轩辕」的方法
 */

var promise;

function exit$2 () {
  promise.then(function () {
    yasuo.page.finish();
  });
}

function hideBar$2 () {
  promise.then(function () {
    yasuo.page.hideBar();
  });
}

function showBar$2 () {
  promise.then(function () {
    yasuo.page.showBar();
  });
}

function init () {
  promise = new Promise(function (resolve) {
    document.addEventListener('yasuoReady', resolve);
  });
  initSDK();
}

// 这段初始化的代码是他们开发提供的，见 /external/eve-sdk.js。
// 没有大幅度的删减代码是因为稍微删的多一点就会导致 SDK 失效，原因未知。
function initSDK () {
  var isAndroid = ua.indexOf('android') > -1;
  var isIOS = ua.indexOf('iphone') > -1;

  function callHandler (name, params, callback) {
    window.WebViewJavascriptBridge.callHandler(name, params, function (res) {
      if (callback) {
        var response = isAndroid ? JSON.parse(res) : res;
        if (response.err) {
          callback(response.err, null);
        } else if (response.res) {
          callback(null, response.res);
        }
      }
    });
  }

  /**
   * 显示 Toast
   */
  function showToast (content, callback) {
    var options = {};
    options.data = JSON.stringify(content) || '';
    callHandler('Toast', JSON.stringify(options), callback);
  }

  /**
   * 页面
   */
  var page = {
    /**
     * 显示导航栏
     */
    showBar: function showBar () {
      callHandler('TitleBar', 'show', null);
    },
    /**
     * 隐藏导航栏
     */
    hideBar: function hideBar () {
      callHandler('TitleBar', 'hide', null);
    },
    /**
     * 关闭当前页面
     */
    finish: function finish () {
      callHandler('Page', 'finish', null);
    },
    /**
     * 显示 loading
     */
    showLoading: function showLoading (options, callback) {
      options = options || {};
      options.mode = 'show';
      callHandler('Loading', options, callback);
    },
    /**
     * 隐藏 loading
     */
    hideLoading: function hideLoading (options, callback) {
      options = options || {};
      options.mode = 'hide';
      callHandler('Loading', options, callback);
    }
  };

  /**
   * 时间选择器
   */
  var timePicker = {
    /**
     * 获取时间
     */
    getTime: function getTime  (options, callback) {
      options = options || {};
      options.mode = 'time';
      callHandler('TimePicker', options, callback);
    },
    /**
     * 获取日期
     */
    getDate: function getDate (options, callback) {
      options = options || {};
      options.mode = 'date';
      callHandler('TimePicker', options, callback);
    },
    /**
     * 获取时间&日期
     */
    getTimeDate: function (options, callback) {
      options = options || {};
      options.mode = 'time_date';
      callHandler('TimePicker', options, callback);
    }
  };

  /**
   * 键盘
   */
  var keyboard = {
    /**
     * 隐藏键盘
     */
    hide: function hide (options, callback) {
      options = options || {};
      options.mode = 'hide';
      callHandler('Keyboard', options, callback);
    },
    /**
     * 显示键盘
     */
    show: function show (options, callback) {
      options = options || {};
      options.mode = 'show';
      callHandler('Keyboard', options, callback);
    }
  };

  /**
   * 相机
   */
  var camera = {
    /**
     * 拍照
     */
    getPicture: function getPicture (options, callback) {
      options = options || {};
      options.mode = 'image';
      callHandler('Camera', options, callback);
    },
    /**
     * 选择照片
     */
    getAlbum: function getAlbum (options, callback) {
      options = options || {};
      options.mode = 'album';
      callHandler('Camera', options, callback);
    }
  };

  var file = {
    /**
     * 上传文件
     */
    transfer: function transfer (options, callback) {
      callHandler('File', options, callback);
    }
  };

  var app = {
    /**
     * 检查更新
     * @function
     * @memberof yasuo.app
     * @param {function} callback 回调函数
     */
    checkVersion: function checkVersion (callback) {
      var options = {};
      options.mode = 'checkVersion';
      callHandler('App', options, callback);
    },
    /**
     * app 信息
     */
    info: function info (callback) {
      var options = {};
      options.mode = 'info';
      callHandler('App', options, callback);
    },
    /**
     * BD 热更新
     */
    hotUpdate: function (callback) {
      var options = {};
      options.mode = 'hotupdate';
      callHandler('App', options, callback);
    }
  };

  /**
   * 设备信息
   */
  var device = function (callback) {
    callHandler('Device', {}, callback);
  };

  var user = {
    /**
     * 登出
     */
    logout: function logout (callback) {
      var options = {};
      options.mode = 'logout';
      callHandler('User', options, callback);
    },
    /**
     * 清除 token
     */
    clearToken: function clearToken (callback) {
      var options = {};
      options.mode = 'clear';
      callHandler('User', options, callback);
    }
  };

  var yasuo = window.yasuo = {
    init: function init (messageHandler) {
      window.WebViewJavascriptBridge.init(messageHandler);
    },
    isAndroid: function isAndroid$1 () {
      return isAndroid
    },
    isIOS: function isIOS$1 () {
      return isIOS
    },
    showToast: showToast,
    camera: camera,
    keyboard: keyboard,
    timePicker: timePicker,
    page: page,
    file: file,
    network: function network (callback) {
      callHandler('NetworkInfo', {}, callback);
    },
    app: app,
    device: device,
    user: user,
    version: '0.0.1'
  };

  // yasuo ready event
  document.addEventListener('WebViewJavascriptBridgeReady', function () {
    var WebViewJavascriptBridge = window.WebViewJavascriptBridge;
    if (!WebViewJavascriptBridge) { return }
    var yasuoReadyEvent = document.createEvent('Events');
    yasuoReadyEvent.initEvent('yasuoReady');
    document.dispatchEvent(yasuoReadyEvent);
    // init
    yasuo.init();
    // keyboard hide and show event
    var yasuoKeyboardHideEvent = document.createEvent('Events');
    yasuoKeyboardHideEvent.initEvent('Keyboard.hide');
    var yasuoKeyboardShowEvent = document.createEvent('Events');
    yasuoKeyboardShowEvent.initEvent('Keyboard.show');
    WebViewJavascriptBridge.registerHandler('Keyboard.hide', function (data, responseCallback) {
      document.dispatchEvent(yasuoKeyboardHideEvent);
    });
    WebViewJavascriptBridge.registerHandler('Keyboard.show', function (data, responseCallback) {
      document.dispatchEvent(yasuoKeyboardShowEvent);
    });
    // screen orientation
    var yasuoScreenLandscape = document.createEvent('Events');
    yasuoScreenLandscape.initEvent('onLandscapeScreen');
    WebViewJavascriptBridge.registerHandler('onLandscapeScreen', function (data, responseCallback) {
      document.dispatchEvent(yasuoScreenLandscape);
    });
    var yasuoScreenPortrait = document.createEvent('Events');
    yasuoScreenPortrait.initEvent('onPortraitScreen');
    WebViewJavascriptBridge.registerHandler('onPortraitScreen', function (data, responseCallback) {
      document.dispatchEvent(yasuoScreenPortrait);
    });
    // network change
    var yasuoNetworkStateChange = document.createEvent('Events');
    yasuoNetworkStateChange.initEvent('networkStateChange');
    WebViewJavascriptBridge.registerHandler('networkStateChange', function (data, responseCallback) {
      yasuoNetworkStateChange.data = data;
      document.dispatchEvent(yasuoNetworkStateChange);
    });
  });
}


var xy = Object.freeze({
	exit: exit$2,
	hideBar: hideBar$2,
	showBar: showBar$2,
	init: init
});

var noop = function () {};

var dd = window.dd;
var exit$3;

if (dd) {
  var promise$1 = new Promise(function (resolve) {
    dd.ready(resolve);
  });
  exit$3 = function () {
    promise$1.then(function () {
      dd.biz.navigation.close();
    });
  };
} else {
  exit$3 = noop;
}




var ding = Object.freeze({
	hideBar: noop,
	showBar: noop,
	get exit () { return exit$3; }
});

/**
 * @file 其它平台的方法，一般是在网页环境里
 */




var other = Object.freeze({
	hideBar: noop,
	showBar: noop,
	exit: noop
});



var platforms = Object.freeze({
	ping: ping,
	xy: xy,
	ding: ding,
	other: other
});

/**
 * @file 这个文件用于保存各种 APP 的 useragent 关键字
 */

var userAgents = {
  xy: 'eve',
  ping: 'qichat',
  ding: 'dingtalk'
};

var hasOwn = Object.prototype.hasOwnProperty;

var platform;

for (var key in userAgents) {
  if (hasOwn.call(userAgents, key)) {
    if (ua.indexOf(userAgents[key]) >= 0) {
      platform = key;
      break
    }
  }
}

// Ping 的 ua 是最近才加上的，
// 这里尝试看看有没有 Ping 的方法
if (!platform) {
  if (window.App && window.App.hideBar) {
    platform = 'ping';
  }
}

var platform$1 = platform || 'other';

var sdk = platforms[platform$1];
if (sdk.init) {
  sdk.init();
}

// 由于 Ping 的 user-agent 没有唯一标志符，所以始终尝试调用一下 Ping 的 API
function hideBar () {
  sdk.hideBar();
  hideBar$1();
}

function showBar () {
  sdk.showBar();
  showBar$1();
}

function exit () {
  sdk.exit();
  exit$1();
}

exports.platform = platform$1;
exports.hideBar = hideBar;
exports.showBar = showBar;
exports.exit = exit;

Object.defineProperty(exports, '__esModule', { value: true });

})));
